@@ -146,19 +146,17 @@ static const char *const g_utf8_skip = utf8_skip_data;
 #define g_utf8_next_char(p) (char *)((p) + g_utf8_skip[*(unsigned char *)(p)])
 
 /**
- * g_utf8_get_char:
+ * stringprep_utf8_to_unichar:
  * @p: a pointer to Unicode character encoded as UTF-8
- * 
+ *
  * Converts a sequence of bytes encoded as UTF-8 to a Unicode character.
  * If @p does not point to a valid UTF-8 encoded character, results are
- * undefined. If you are not sure that the bytes are complete
- * valid Unicode characters, you should use g_utf8_get_char_validated()
- * instead.
- * 
+ * undefined.
+ *
  * Return value: the resulting character
  **/
-static long
-g_utf8_get_char (const char * p)
+long
+stringprep_utf8_to_unichar (const char *p)
 {
   int i, mask = 0, len;
   long result;
@@ -166,7 +164,7 @@ g_utf8_get_char (const char * p)
 
   UTF8_COMPUTE (c, mask, len);
   if (len == -1)
-    return (long) - 1;
+    return (long) -1;
   UTF8_GET (result, p, i, mask, len);
 
   return result;
@@ -185,13 +183,13 @@ g_utf8_get_char (const char * p)
  * @string: a UCS-4 encoded string.
  * @len: the maximum length of @string to use.
  *
- * Computes the canonical ordering of a string in-place.  
- * This rearranges decomposed characters in the string 
- * according to their combining classes.  See the Unicode 
- * manual for more information. 
+ * Computes the canonical ordering of a string in-place.
+ * This rearranges decomposed characters in the string
+ * according to their combining classes.  See the Unicode
+ * manual for more information.
  **/
 static void
-g_unicode_canonical_ordering (long * string, size_t len)
+g_unicode_canonical_ordering (long *string, size_t len)
 {
   size_t i;
   int swap = 1;
@@ -280,7 +278,7 @@ find_decomposition (long ch, int compat)
      (((Char) > (G_UNICODE_LAST_CHAR)) ? 0 : CI((Char) >> 8, (Char) & 0xff))
 
 static int
-combine (long a, long b, long * result)
+combine (long a, long b, long *result)
 {
   int index_a, index_b;
 
@@ -330,7 +328,7 @@ combine (long a, long b, long * result)
 }
 
 static long *
-_g_utf8_normalize_wc (const char * str, int max_len, GNormalizeMode mode)
+_g_utf8_normalize_wc (const char *str, int max_len, GNormalizeMode mode)
 {
   size_t n_wc;
   long *wc_buffer;
@@ -343,7 +341,7 @@ _g_utf8_normalize_wc (const char * str, int max_len, GNormalizeMode mode)
   p = str;
   while ((max_len < 0 || p < str + max_len) && *p)
     {
-      long wc = g_utf8_get_char (p);
+      long wc = stringprep_utf8_to_unichar (p);
 
       const unsigned char *decomp = find_decomposition (wc, do_compat);
 
@@ -361,14 +359,14 @@ _g_utf8_normalize_wc (const char * str, int max_len, GNormalizeMode mode)
       p = g_utf8_next_char (p);
     }
 
-  wc_buffer = malloc (sizeof(long) * (n_wc + 1));
+  wc_buffer = malloc (sizeof (long) * (n_wc + 1));
 
   last_start = 0;
   n_wc = 0;
   p = str;
   while ((max_len < 0 || p < str + max_len) && *p)
     {
-      long wc = g_utf8_get_char (p);
+      long wc = stringprep_utf8_to_unichar (p);
       const unsigned char *decomp;
       int cc;
       size_t old_n_wc = n_wc;
@@ -458,13 +456,13 @@ _g_utf8_normalize_wc (const char * str, int max_len, GNormalizeMode mode)
  * @outbuf: output buffer, must have at least 6 bytes of space.
  *       If %NULL, the length will be computed and returned
  *       and nothing will be written to @outbuf.
- * 
+ *
  * Converts a single character to UTF-8.
- * 
+ *
  * Return value: number of bytes written
  **/
 int
-stringprep_unichar_to_utf8 (long c, char * outbuf)
+stringprep_unichar_to_utf8 (long c, char *outbuf)
 {
   int len = 0;
   int first;
@@ -515,7 +513,7 @@ stringprep_unichar_to_utf8 (long c, char * outbuf)
 }
 
 /**
- * stringgprep_utf8_to_ucs4_fast:
+ * stringgprep_utf8_to_ucs4:
  * @str: a UTF-8 encoded string
  * @len: the maximum length of @str to use. If @len < 0, then
  *       the string is nul-terminated.
@@ -524,16 +522,13 @@ stringprep_unichar_to_utf8 (long c, char * outbuf)
  *
  * Convert a string from UTF-8 to a 32-bit fixed width
  * representation as UCS-4, assuming valid UTF-8 input.
- * This function is roughly twice as fast as g_utf8_to_ucs4()
- * but does no error checking on the input.
- * 
+ * This function does no error checking on the input.
+ *
  * Return value: a pointer to a newly allocated UCS-4 string.
  *               This value must be freed with g_free().
  **/
 long *
-stringprep_utf8_to_ucs4_fast (const char *str,
-			      int  len,              
-			      int *items_written)    
+stringprep_utf8_to_ucs4 (const char *str, int len, int *items_written)
 {
   int j, charlen;
   long *result;
@@ -558,13 +553,13 @@ stringprep_utf8_to_ucs4_fast (const char *str,
 	  ++n_chars;
 	}
     }
-  
-  result = malloc(sizeof(long) * (n_chars + 1));
-  
+
+  result = malloc (sizeof (long) * (n_chars + 1));
+
   p = str;
-  for (i=0; i < n_chars; i++)
+  for (i = 0; i < n_chars; i++)
     {
-      long wc = ((unsigned char *)p)[0];
+      long wc = ((unsigned char *) p)[0];
 
       if (wc < 0x80)
 	{
@@ -572,7 +567,7 @@ stringprep_utf8_to_ucs4_fast (const char *str,
 	  p++;
 	}
       else
-	{ 
+	{
 	  if (wc < 0xe0)
 	    {
 	      charlen = 2;
@@ -602,7 +597,7 @@ stringprep_utf8_to_ucs4_fast (const char *str,
 	  for (j = 1; j < charlen; j++)
 	    {
 	      wc <<= 6;
-	      wc |= ((unsigned char *)p)[j] & 0x3f;
+	      wc |= ((unsigned char *) p)[j] & 0x3f;
 	    }
 
 	  result[i] = wc;
@@ -617,6 +612,15 @@ stringprep_utf8_to_ucs4_fast (const char *str,
   return result;
 }
 
+/* This one is kept around for binary backwards compatibility with
+   library version CURRENT=1. */
+long *
+stringprep_utf8_to_ucs4_fast (const char *str, int len, int *items_written)
+{
+  return stringprep_utf8_to_ucs4 (str, len, items_written);
+
+}
+
 /**
  * g_ucs4_to_utf8:
  * @str: a UCS-4 encoded string
@@ -625,22 +629,22 @@ stringprep_utf8_to_ucs4_fast (const char *str,
  * @items_read: location to store number of characters read read, or %NULL.
  * @items_written: location to store number of bytes written or %NULL.
  *                 The value here stored does not include the trailing 0
- *                 byte. 
+ *                 byte.
  * @error: location to store the error occuring, or %NULL to ignore
  *         errors. Any of the errors in #GConvertError other than
  *         %G_CONVERT_ERROR_NO_CONVERSION may occur.
  *
  * Convert a string from a 32-bit fixed width representation as UCS-4.
  * to UTF-8. The result will be terminated with a 0 byte.
- * 
+ *
  * Return value: a pointer to a newly allocated UTF-8 string.
  *               This value must be freed with g_free(). If an
  *               error occurs, %NULL will be returned and
  *               @error set.
  **/
 char *
-stringprep_ucs4_to_utf8 (const long * str,
-			 int len, int * items_read, int * items_written)
+stringprep_ucs4_to_utf8 (const long *str,
+			 int len, int *items_read, int *items_written)
 {
   int result_length;
   char *result = NULL;
@@ -688,7 +692,7 @@ err_out:
  * @str: a UTF-8 encoded string.
  * @len: length of @str, in bytes, or -1 if @str is nul-terminated.
  * @mode: the type of normalization to perform.
- * 
+ *
  * Converts a string into canonical form, standardizing
  * such issues as whether a character with an accent
  * is represented as a base character and combining
@@ -715,12 +719,12 @@ err_out:
  * useful if you intend to convert the string to
  * a legacy encoding or pass it to a system with
  * less capable Unicode handling.
- * 
- * Return value: a newly allocated string, that is the 
+ *
+ * Return value: a newly allocated string, that is the
  *   normalized form of @str.
  **/
 static char *
-g_utf8_normalize (const char * str, int len, GNormalizeMode mode)
+g_utf8_normalize (const char *str, int len, GNormalizeMode mode)
 {
   long *result_wc = _g_utf8_normalize_wc (str, len, mode);
   char *result;
@@ -745,8 +749,7 @@ stringprep_ucs4_nfkc_normalize (long *str, int len)
 
   p = stringprep_ucs4_to_utf8 (str, len, 0, 0);
   result_wc = _g_utf8_normalize_wc (p, -1, G_NORMALIZE_NFKC);
-  free(p);
+  free (p);
 
   return result_wc;
 }
-
